@@ -1,16 +1,8 @@
-import sys
 import hashlib
-from math import ceil, exp, log
+from math import ceil, exp, log, log2
 
 from bitarray import bitarray
 
-if sys.version_info[0] == 2:
-    int = long
-    range = xrange
-    log2 = lambda x: log(x, 2.0)
-else:
-    from math import log2
-
 
 class BloomFilter(object):
     """
@@ -48,8 +40,7 @@ class BloomFilter(object):
         return -float(self.m) / self.k * log(1.0 - float(count) / self.m)
 
     def add(self, key):
-        for i in self._hashes(key):
-            self.array[i] = 1
+        self.array[list(self._hashes(key))] = 1
 
     def __contains__(self, key):
         return all(self.array[i] for i in self._hashes(key))
